#!/usr/bin/perl -w

# Script to extract scores from a set of alignments and 
# generate an accuracy plot in postscript format
# uses the R package to generate postscript, requires R from http://r-project.org
# Usage: scoregen <score output file> [backbone]
# if collating scores on backbone regions use the backbone option
#

use strict;
require simujobparams;
use simujobparams;

if( @ARGV != 2 ){
	print STDERR "Usage: scoregen <postscript output file> [backbone]\n";
	exit;
}

my $total_alignments = $simujobparams::x_count * $simujobparams::y_count;
my $score_infilename = "scores.txt";
$score_infilename = "bb_scores.txt" if $ARGV[1] eq "backbone";
my $plot_outfilename = $ARGV[0];
my $tmp_scorefile = "/tmp/scores.txt";
my $fname_ext = "dat";
my $evolved_name = "evolved.dat";
print "x_var is: $simujobparams::x_variable, y_var is: $simujobparams::y_variable\n"; 

# create an array with the score values in it
my @data_values;
my @data_count;
for( my $dataI = 0; $dataI < $data_rows * $data_cols; $dataI++ ){
        $data_values[ $dataI ] = 0;
        $data_count[ $dataI ] = 0;
}


open( SCOREOUT, ">$tmp_scorefile" );
my $alignjob = 0;
for( my $x_val = 0; $x_val < $simujobparams::x_count; $x_val++ ){
	for( my $y_val = 0; $y_val < $simujobparams::y_count; $y_val++ ){
	        my $tmp_score = "alignjob.$alignjob/$score_infilename";
	        next if !(-e $tmp_score );
	
	        open( SCOREFILE, "$tmp_score" );
	        my $score = -1;
	        while( my $cur_line = <SCOREFILE> ){
	                if( $cur_line =~ /TP \+ TN \/ total/ ){
	                        my @vals = split( / = /, $cur_line);
	                        $score = $vals[1];
	                        chomp $score;
	                }
	        }
	        close SCOREFILE;

	        my $cur_x = round( $cur_values[0] / $x_increment );
	        my $cur_y = round( $cur_values[1] / $y_increment );
	        $data_values[ $y_val * $simujobparams::y_count + $x_val ] += $score;
	        $data_count[ $y_val * $simujobparams::y_count + $x_val ]++;


		$alignjob++;
		
	}
}

# write out a temporary file with all the score values
# in a form parseable by R 
open( GRADIENTFILE, ">$gradient_filename" );

my $valueI = 0;
#for( my $rowI = $data_rows; $rowI > 0; $rowI-- ){
for( my $rowI = 0; $rowI < $simujobparams::x_count; $rowI++ ){
        for( my $colI = 0; $colI < $simujobparams::y_count; $colI++ ){
                my $valueI = $rowI * $simujobparams::y_count + $colI;
                my $cur_value = $data_values[ $valueI ];
                if( $data_count[ $valueI ] > 0 ){
                        $cur_value /= $data_count[ $valueI ];
                }
                print GRADIENTFILE $cur_value;
                print GRADIENTFILE "\n";
        }
}

close GRADIENTFILE;

chomp(my $cwd = `pwd`);
chdir($data_dir);
my $r_cmd = "R CMD BATCH $simujobparams::tools_dir/rgradientplot.R";
system( $r_cmd );
`mv scoreplot.ps $plot_outfilename`;


exit 0;

sub round { return int($_[0]) + (($_[0]*10%10 >= 5) ? 1 : 0); }
